%define anolis_release 1
%bcond_with websupport
%bcond_with tests
%bcond_with imagemagick_tests
%bcond_with latex_tests

%global py3_shebang_flags %(echo %py3_shebang_flags | sed s/s//)
%global upstream_name Sphinx

Name:		python-sphinx
Version:	6.1.3
Release:	%{anolis_release}%{?dist}
Summary:	Python documentation generator
License:	BSD and Python and MIT
URL:		https://www.sphinx-doc.org/
Source0:        %{pypi_source %{upstream_name} %{version}}

BuildArch:      noarch

BuildRequires:	make
BuildRequires:  python3-devel
BuildRequires:  python3-tomli
	
%if %{with websupport}
BuildRequires: python3-sphinxcontrib-websupport
%endif
BuildRequires: dos2unix
%if %{with tests}
BuildRequires: gcc
BuildRequires: gettext
BuildRequires: graphviz
BuildRequires: texinfo
BuildRequires: python3-test
%if %{with imagemagick_tests}
BuildRequires: ImageMagick
%endif
%if %{with latex_tests}
BuildRequires: texlive-collection-fontsrecommended
BuildRequires: texlive-collection-latex
BuildRequires: texlive-dvipng
BuildRequires: texlive-dvisvgm
BuildRequires: tex(amsmath.sty)
BuildRequires: tex(amsthm.sty)
BuildRequires: tex(anyfontsize.sty)
BuildRequires: tex(article.cls)
BuildRequires: tex(capt-of.sty)
BuildRequires: tex(cmap.sty)
BuildRequires: tex(color.sty)
BuildRequires: tex(ctablestack.sty)
BuildRequires: tex(fancyhdr.sty)
BuildRequires: tex(fancyvrb.sty)
BuildRequires: tex(fncychap.sty)
BuildRequires: tex(framed.sty)
BuildRequires: tex(FreeSerif.otf)
BuildRequires: tex(geometry.sty)
BuildRequires: tex(hyperref.sty)
BuildRequires: tex(kvoptions.sty)
BuildRequires: tex(luatex85.sty)
BuildRequires: tex(needspace.sty)
BuildRequires: tex(parskip.sty)
BuildRequires: tex(polyglossia.sty)
BuildRequires: tex(tabulary.sty)
BuildRequires: tex(titlesec.sty)
BuildRequires: tex(upquote.sty)
BuildRequires: tex(utf8x.def)
BuildRequires: tex(wrapfig.sty)
%endif
%endif

%description
Sphinx makes it easy to create intelligent and beautiful documentation.

Sphinx uses reStructuredText as its markup language, and many of its 
strengths come from the power and straightforwardness of reStructuredText 
and its parsing and translating suite, the Docutils.

%package -n python3-sphinx
Summary:       Python documentation generator
Recommends:    graphviz
Recommends:    ImageMagick
# Bundled JavaScript
Provides:      bundled(jquery) = 3.5.1
Provides:      bundled(underscore) = 1.3.1
Provides:      bundled(css3-mediaqueries) = 1.0
Provides:      python3-sphinx-latex = %{version}-%{release}

%description -n python3-sphinx
Sphinx makes it easy to create intelligent and beautiful documentation.

Sphinx uses reStructuredText as its markup language, and many of its
strengths come from the power and straightforwardness of reStructuredText
and its parsing and translating suite, the Docutils

%package -n python3-sphinx-doc
Summary:        Documentation files for python3-sphinx
License:        BSD
Requires:       python3-sphinx = %{version}-%{release}
BuildArch:      noarch

%description -n python3-sphinx-doc
The python3-sphinx-doc package contains documentation files for python3-sphinx.

%prep
%autosetup -n %{upstream_name}-%{version} -p1

%if %{without imagemagick_tests}
rm tests/test_ext_imgconverter.py
%endif

%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x test}

%build
%pyproject_wheel
	
export PYTHONPATH=$PWD
pushd doc
export SPHINXBUILD="%{python3} ../sphinx/cmd/build.py"
make html SPHINXBUILD="$SPHINXBUILD"
make man SPHINXBUILD="$SPHINXBUILD"
mv _build/html ..
popd

%install
%pyproject_install

# For backwards compatibility. Remove with care, if at all
for i in sphinx-{apidoc,autogen,build,quickstart}; do
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-%{python3_version}
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-3
done

# Clean up non-python files
rm -f %{buildroot}%{python3_sitelib}/sphinx/locale/.DS_Store
rm -rf %{buildroot}%{python3_sitelib}/sphinx/locale/.tx

pushd doc
# Deliver man pages
install -d %{buildroot}%{_mandir}/man1
for f in _build/man/sphinx-*.1;
do
    cp -p $f %{buildroot}%{_mandir}/man1/$(basename $f)
done
popd

pushd %{buildroot}%{python3_sitelib}
for lang in `find sphinx/locale -maxdepth 1 -mindepth 1 -type d -not -path '*/\.*' -printf "%f "`;
do
  test $lang == __pycache__ && continue
  install -d %{buildroot}%{_datadir}/sphinx/locale/$lang
  install -d %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.js \
     %{buildroot}%{_datadir}/sphinx/locale/$lang/
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.mo \
    %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/
  rm -rf sphinx/locale/$lang
done
popd

mkdir %{buildroot}%{python3_sitelib}/sphinxcontrib

%find_lang sphinx
 
# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang

%if %{with tests}
%check
# Currently, all linkcheck tests and test_latex_images need internet
%pytest \
%if %{without internet}
    -k "not linkcheck and not test_latex_images" \
%endif
;
%endif

%files -n python3-sphinx -f sphinx.lang
%license LICENSE AUTHORS
%{_bindir}/sphinx-*
%{python3_sitelib}/sphinx/
%dir %{python3_sitelib}/sphinxcontrib/
%{python3_sitelib}/sphinx-%{version}.dist-info/
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*
%{_mandir}/man1/sphinx-*

	
%files -n python3-sphinx-doc
%doc html
%doc CHANGES EXAMPLES README.rst

%changelog
* Wed Mar 08 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 6.1.3-1
- update to version 6.1.3

* Thu Sep 15 2022 happy_orange <songnannan@linux.alibaba.com> - 5.1.1-1
- Init pacakge from upstream

